from setuptools import setup

setup(name='gauzz_binom',
      version='1.1',
      description='Binomial and Gaussian distributions',
      packages=['gauzz_binom'],
      author= 'Hakeem Mabby',
      authon_email= 'hakeem@example.com',      
      zip_safe=False)
